---
title: "Retropie: support des jeux Wii et GameCube"
...

Ce tutoriel explique comment faire fonctionner ses jeux Wii et GameCube.
Cette méthode ne s'applique qu'à une installation PC de Retropie, et
est incompatible avec une installation RaspberryPi.

Ce tutoriel est lié au tutoriel [Installation de RetroPie sur
PC](https://sitelec.org/download_page.php?filename=cours/mathieu/arcade_pc/install.pdf).

Installation de l'émulateur
----------------------------

Nous allons utiliser l'émulateur Dolphin, qui est dédié aux jeux Wii et
GameCube. Plus précisément, nous allons utiliser **lr-dolphin**, qui est
un *core* RetroArch pour Dolphin, permettant une bonne
intégration de l'émulateur avec RetroPie, notamment au niveau de la
gestion des manettes et joysticks.

Dans votre interface EmulationStation, allez sur le menu **RetroPie**,
puis **RetroPie setup**. Dans la fenêtre qui apparaît, rendez-vous dans
le menu **Manage packages**, **Manage experimental packages**,
**lr-dolphin**, **Install from source**.

Une fois l'installation terminée, quittez l'outil de configuration
RetroPie.

> ![image](attention.png) **Attention:**
> Si vous avez suivi le tutoriel [Installation de jeux PC et Steam avec
> Retropie](https://sitelec.org/download_page.php?filename=cours/mathieu/arcade_pc/pc_steam_games.pdf),
> vous avez probablement défini manuellement
> */opt/retropie/configs/all/emulationstation/es\_systems.cfg*, pour y ajouter
> une entrée spécifique aux jeux PC. Si tel est le cas, vous **devez** à
> présent reporter manuellement les blocs **wii** et **gc** de
> */etc/emulationstation/es\_systems.cfg* vers votre fichier
> */opt/retropie/configs/all/emulationstation/es\_systems.cfg*.

Ajout des jeux
--------------

> ![image](note.png) **Note:**
> Certains jeux Wii nécessitent obligatoirement une Wiimote ou un nunchuck pour
> être jouables. Si vous jouez sur votre machine avec un joystick et des
> boutons, seuls les jeux au gameplay compatible avec des manettes classiques
> seront jouables, comme par exemple Mario Kart Wii.

Placez vos jeux Wii dans le répertoire */home/pi/RetroPie/roms/wii*, et vos
jeux GameCube dans le répertoire */home/pi/RetroPie/roms/gc*. Les extensions de
fichiers compatibles sont: *.iso, .wbfs, .elf, .gcm, .dol, .tgc, .ciso, .gcz,
et .wad*.

Une fois vos jeux placés, vous pouvez redémarrer EmulationStation, et
vous verrez apparaître un menu Wii et/ou un menu GameCube.

Paramétrage des contrôleurs de jeu
----------------------------------

Il faut à présent que vos contrôleurs de jeux soient vus par
l'émulateur comme des manettes de Wii ou de GameCube.

Nous prendrons comme exemple dans ce tutoriel des contrôleurs style
arcade: un joystick + des boutons pour chaque joueur. Pour ce style de
contrôleur, vous avez probablement configuré RetroPie pour que le
joystick agisse tel un pad directionnel: par exemple si le joystick est
actionné vers le haut, l'action **UP** est effectuée.

Sur la Wii et la GameCube, il est possible que vos jeux n'utilisent pas
le pad directionnel, le stick analogique étant utilisé à la fois pour
naviguer dans les menus et pour le jeu.

Si tel est le cas, vous pouvez réassigner vos contrôles. Dans un jeu,
appuyez sur **Hotkey+X**, vous accédez ainsi au *Quick Menu*
de Retroarch. Dans le sous-menu *Controls* vous aurez accès
aux options de réassignation. Remplacez respectivement:

-   Up **\>** Control Stick Y-
-   Down **\>** Control Stick Y+
-   Left **\>** Control Stick X-
-   Right **\>** Control Stick X+

de façon à ce que le joystick soit vu par le jeu tel un stick analogique.
Procédez de la même manière pour chaque contrôleur utilisé (User 1, User
2\...).

![Directions analogiques](analog_directions.jpg){width="25%"}

> ![image](note.png) **Note:**
> *Control Stick* ci-dessus est nommé comme tel sur GameCube, et sera nummé
> *Left Stick* dans le cas de la Wii.

![Réassignation du contrôleur analogique](controller_analog_remapping.jpg){width="75.0%"}

Ensuite, vous pouvez au choix:

1.  enregistrer cette réassignation pour l'ensemble des jeux de cet
    émulateur en choisissant **Save Core Remap File**,
2.  ou enregistrer cette réassignation pour un seul jeu, en choisissant
    **Save Game Remap File**.

Si vous avez choisi l'option **1**, refaites cette opération pour un
jeu Wii et pour un jeu GameCube de façon à ce que les deux consoles
bénéficient de la réassignation.

Vous pouvez également réassigner d'autres boutons si vous estimez que
les contrôles Wii / GameCube sont mal disposés sur vos boutons arcade.

Une fois les modifications terminées, **Hotkey+X** permet de quitter le
*Quick Menu*.

### Cas particulier de la Wii

Pour qu'un contrôleur de type arcade fonctionne correctement avec
l'émulateur Wii, il va falloir le configurer en tant que [Classic
Controller]{.title-ref}. Pour celà, rendez-vous dans le [Quick
Menu]{.title-ref} de Retroarch, en pressant **Hotkey+X**, et allez
ensuite dans le sous-menu *Controls*.

Modifiez l'option *User 1 device type* pour [Wiimote +
Classic Controler]{.title-ref}, et faites de même pour chaque contrôleur
utilisé (User 2, User 3\...).

![Wii Classic Controller](controller_wii_classic.jpg){width="75.0%"}

Réglages
--------

### Ne plus afficher les messages informatifs à l'écran

L'émulateur affiche certains messages informatifs à l'écran, comme la
carte graphique utilisée, en jaune, au démarrage du jeu. Pour cacher ces
messages dans les jeux Wii, éditez
*\~/RetroPie/roms/wii/User/Config/Dolphin.ini* et changez:

    OnScreenDisplayMessages = True

pour:

    OnScreenDisplayMessages = False

Effectuez la même modification pour les jeux GameCube en éditant
*\~/RetroPie/roms/gc/User/Config/Dolphin.ini*.

### Wii: masquer les écrans relatifs à l'utilisation de la Wiimote

Au démarrage des jeux, vous pouvez voir des écrans relatifs à
l'utilisation de la Wiimote. Sur une borne d'arcade sans Wiimote, ces
écrans n'ont pas d'intérêt. Nous allons donc ici aborder une méthode
simple pour les masquer, qui consiste tout simplement à les remplacer
par une autre image.

Téléchargez l'émulateur Dolphin depuis le site officiel
<https://fr.dolphin-emu.org>, et installez-le sur votre PC.

Nous allons tout d'abord paramétrer Dolphin pour qu'il extraie les
textures chargées en RAM par le jeu. Lancez Dolphin, et allez dans le
menu **Configurer**, onglet **Dossiers**. Définissez **Dossier de dump**
vers un dossier de votre choix, où les textures seront exportées.
Ensuite, dans le menu **Graphismes**, onglet **Acancé**, dans la section
**Utilitaires** cochez la case **Copier les textures**.

Au cours de l'utilisation du jeu, toutes les textures chargées en RAM
seront sauegardées dans le dossier qui a été défini.

Identifiez l'un de vos jeux pour lequel vous souhaitez retirer les
écrans Wiimote, et lancez-le. Une fois les écrans relatifs à
l'utilisation de la Wiimote passés, quittez le jeu.

Rendez-vous dans le répertoire que vous avez configuré, vous devriez y
trouver un certain nombres d'images, qui sont les textures qui ont été
chargées par le jeu pendant sa durée d'utilisation.

Repérez les textures qui sont relatives à l'utilisation de la Wiimote,
et notez leur nom de fichier ainsi que leur résolution. Notez également
le nom du dossier qui contient les textures extraites.

> ![image](note.png) **Note:**
> Selon les jeux, un écran d'informations Wiimote peut-être une seule et même
> image, ou une composition d'un ensemble d'image. Dans ce second cas, vous
> devrez modifier l'ensemble de ces images.

Sur votre système RetroPie, lancez un jeu Wii, puis appuyez sur
**Hotkey+X** puis allez dans le menu **Options** de Retroarch. Passez
l'option **Load Custom Textures** à **enabled**. Ce paramètre indique à
Dolphin qu'il doit charger des textures de remplacement, si elles
existent.

> ![image](attention.png) **Attention:**
> Veilliez à ce que Dolphin soit configuré avec le même langage par défaut sur
> votre PC et sur votre machine RetroPie, en effet des textures différentes
> pourraient-être utilisées suivant la langue utilisée. Sur PC vous pouvez
> paramétrer la langue dans le menu **Configuration**, onglets **Wii** et
> **GameCube**. Sur RetroPie, le menu **Options** de Retroarch (évoqué
> précédemment) vous permet de sélectionner la langue.

Ensuite, sur votre système RetroPie, créez le dossier
*\~/RetroPie/roms/wii/User/Load/Textures* s'il n'existe
pas déjà, et créez à l'intérieur un répertoire nommé comme le
répertoire dans lequel les textures ont été directement extraites sur
votre PC.

Pour chaque texture que vous voulez modifier, créez avec votre logiciel
de graphisme préféré une image portant le même nom et dont la résolution
est identique, et placez-là dans ce répertoire.

À présent, lors du lancement du jeu sur votre système RetroPie, les
écrans relatifs à l'utilisation de la Wiimote n'apparaîtront plus et
seront remplacés par vos propres images.

Résolution des problèmes
------------------------

### Mario Kart Wii

Si vous obtenez l'erreur [\"Could not write to/read from Wii system
memory\"]{.title-ref}, téléchargez le fichier suivant:
<https://sitelec.org/cours/mathieu/arcade_pc/wii_mariokart_title.tar.xz>

et décompressez-le dans le répertoire
*\~/RetroPie/roms/wii/User/Wii*.
